==> certmanager-model-v1alpha2-5.12.3-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/OrderBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class OrderBuilder extends io.fabric8.certmanager.api.model.acme.v1alpha2.OrderFluentImpl<io.fabric8.certmanager.api.model.acme.v1alpha2.OrderBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.certmanager.api.model.acme.v1alpha2.Order,io.fabric8.certmanager.api.model.acme.v1alpha2.OrderBuilder>{
  public OrderBuilder() {
    this(false);
  }
  public OrderBuilder(java.lang.Boolean validationEnabled) {
    this(new Order(), validationEnabled);
  }
  public OrderBuilder(io.fabric8.certmanager.api.model.acme.v1alpha2.OrderFluent<?> fluent) {
    this(fluent, false);
  }
  public OrderBuilder(io.fabric8.certmanager.api.model.acme.v1alpha2.OrderFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Order(), validationEnabled);
  }
  public OrderBuilder(io.fabric8.certmanager.api.model.acme.v1alpha2.OrderFluent<?> fluent,io.fabric8.certmanager.api.model.acme.v1alpha2.Order instance) {
    this(fluent, instance, false);
  }
  public OrderBuilder(io.fabric8.certmanager.api.model.acme.v1alpha2.OrderFluent<?> fluent,io.fabric8.certmanager.api.model.acme.v1alpha2.Order instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  public OrderBuilder(io.fabric8.certmanager.api.model.acme.v1alpha2.Order instance) {
    this(instance,false);
  }
  public OrderBuilder(io.fabric8.certmanager.api.model.acme.v1alpha2.Order instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.certmanager.api.model.acme.v1alpha2.OrderFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.certmanager.api.model.acme.v1alpha2.Order build() {
    Order buildable = new Order(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OrderBuilder that = (OrderBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> certmanager-model-v1alpha2-6.4.1-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/OrderBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class OrderBuilder extends OrderFluentImpl<OrderBuilder> implements VisitableBuilder<Order,OrderBuilder>{
  public OrderBuilder() {
    this(false);
  }
  public OrderBuilder(Boolean validationEnabled) {
    this(new Order(), validationEnabled);
  }
  public OrderBuilder(OrderFluent<?> fluent) {
    this(fluent, false);
  }
  public OrderBuilder(OrderFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Order(), validationEnabled);
  }
  public OrderBuilder(OrderFluent<?> fluent,Order instance) {
    this(fluent, instance, false);
  }
  public OrderBuilder(OrderFluent<?> fluent,Order instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  public OrderBuilder(Order instance) {
    this(instance,false);
  }
  public OrderBuilder(Order instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  OrderFluent<?> fluent;
  Boolean validationEnabled;
  public Order build() {
    Order buildable = new Order(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    return buildable;
  }
  
}
